MasterConfig

Struct MasterConfig 

pub struct MasterConfig { /* private fields */ }
This struct represents the configuration file for the master. This file contains the Python code for the builders and the schedulers. In addition, it contains some basic data such as the title for the web ui, the title url for the webui, and so on.

For more information on how the master configuration file works, see the documentation for buildbot on their website: https://buildbot.net/

Implementations

Source

impl MasterConfig

This is impl the for MasterConfig struct.

pub fn set_mail_notifier(&mut self, mail_notifier: MailNotifier)

pub fn get_workers(&self) -> Vec<Worker>