Worker

Struct Worker 

pub struct Worker { /* private fields */ }
This struct holds the information that is used to build the worker buildbot.tac file Each worker has:

  • a name that is used by the builders to assign work,
  • a password that the master uses to access the worker
  • a working directory name that the bot will be created in
  • the host address of the master bot, the ip
  • the port of the master bot

Implementations

Source

impl Worker

pub fn get_name(&self) -> String

Retrieves the name field of the struct

pub fn get_dir(&self) -> String

Retrieves the working dir field of the struct

pub fn get_password(&self) -> String

Retrieves the password field of the struct