pub struct Worker { /* private fields */ }Expand description
This struct holds the information that is used to build the worker buildbot.tac file
Each worker has:
- a name that is used by the builders to assign work,
- a password that the master uses to access the worker
- a working directory name that the bot will be created in
- the host address of the master bot, the ip
- the port of the master bot
Implementations